======
PyDAIR
======


Sequencing immunoglobulin using high-throughput sequencing platform (Ig-Seq)
enables to snapshot the adaptive immune repertoires,
giving us the insights to better understanding immune responses in health and disease.
Large amounts of raw data produced by Ig-Seq require effective ways for anlaysis.
PyDAIR is a tool that aims to identify V, D, J and CDR3 segments,
and detects insertions and deletions on V-D and D-J junctions.


